@@ -27,7 +27,7 @@ use constant  AWS_CONTAINER_CREDENTIALS_URL          => 'http://169.254.170.2';
 
 use vars qw/$VERSION @EXPORT/;
 
-$VERSION = '1.0.8-0'; $VERSION=~s/\-.*$//;
+$VERSION = '1.0.9-0'; $VERSION=~s/\-.*$//;
 
 @EXPORT = qw/$VERSION/;
 
@@ -437,9 +437,12 @@ sub is_token_expired {
 
   if ( defined $expiration_date ) {
     # AWS recommends getting credentials 5 minutes prior to expiration
-    my $g = timegm(strptime($expiration_date, "%Y-%m-%dT%H:%M:%S%z"));
+    my $g = _iso8601_to_time($expiration_date);
+
+    # shave 5 minutes or window interval off of the expiration time
     $g -= $window_interval * 60;
 
+    # (expiration_time - window_interval) - current_time = # of seconds left before expiration
     my $seconds_left = $g - time;
 
     if ( $self->get_debug ) {
@@ -458,6 +461,14 @@ sub is_token_expired {
   return $expired;
 }
 
+sub _iso8601_to_time {
+  my $iso8601 = shift;
+  
+  $iso8601 =~s/^(.*)Z$/$1\+00:00/;
+  
+  return timegm(strptime($iso8601, "%FT%T%z"));
+}
+
 =pod
 
 =head2 get_creds_from_role
